@@ -173,9 +173,7 @@ class system(object):
         self.tz = geo.zipToTZ(self.zipcode)
         self.name, self.usaf = geo.closestUSAF(self.place)
 
-    def model(self,modelName = 'p9'):
-        from multiprocessing import Pool
-        from multiprocessing import cpu_count
+    def model(self,modelName = 'p9',singleThread=False):
 
         #hack for threading
         #probably should be abstracted some other way
@@ -185,10 +183,15 @@ class system(object):
         properties['azimuth'] = self.azimuth
         properties['modelName'] = modelName
 
-        pool = Pool(processes=cpu_count())
-        #still a hack
-        insolationOutput = pool.map(_calc,[(properties, i) for i in tmy3.data(self.usaf)])
-        pool.close()
+        if singleThread:
+            insolationOutput = map(_calc,[(properties, i) for i in tmy3.data(self.usaf)])
+        else:
+            from multiprocessing import Pool
+            from multiprocessing import cpu_count
+            pool = Pool(processes=cpu_count())
+            #still a hack
+            insolationOutput = pool.map(_calc,[(properties, i) for i in tmy3.data(self.usaf)])
+            pool.close()
 
         houlyTimeseries = np.array([])
         hourlyInsolation = np.array([])
@@ -202,14 +205,20 @@ class system(object):
         dailyMax = 0
         clip = 0
 
+        #cache
+        NOLOAD = self.Pac(0)
+
         for timestamp,insolation,record in insolationOutput:
-            houlyTimeseries = np.append(houlyTimeseries,timestamp)
-            tAmb = float(record['Dry-bulb (C)'])
-            windSpd = float(record['Wspd (m/s)'])
-            tModule = .945*tAmb +.028*insolation - 1.528*windSpd + 4.3
-            if hasattr(self,'hourlyShade'):
-                insolation = insolation * self.hourlyShade.shade(timestamp)
-            output = self.Pac(insolation,tModule)
+            if insolation > 0:
+                houlyTimeseries = np.append(houlyTimeseries,timestamp)
+                tAmb = float(record['Dry-bulb (C)'])
+                windSpd = float(record['Wspd (m/s)'])
+                tModule = .945*tAmb +.028*insolation - 1.528*windSpd + 4.3
+                if hasattr(self,'hourlyShade'):
+                    insolation = insolation * self.hourlyShade.shade(timestamp)
+                output = self.Pac(insolation,tModule)
+            else:
+                output = NOLOAD
             #output = self.Pac(insolation)
             hourlyInsolation = np.append(hourlyInsolation,output)
 
